@@ -180,6 +180,20 @@ def main():
 
     sys.path.append(d)"""
     #file=os.path.expanduser("~/.copy_to_confs.json")
+    if not os.path.exists(folder):
+        os.makedirs(folder)
+
+    if not os.path.exists(file):
+        with open(file, "w") as outfile:
+            json.dump({}, outfile)
+
+    with open(file, 'r') as outfile:
+        envs = json.load(outfile)
+
+    with open(file, 'w') as outfile: 
+        if not 'group' in envs:
+            envs['group'] = [] 
+            json.dump(envs, outfile)
 
     parser = get_main_parser()
     args = parser.parse_args()
